@@ -4,15 +4,12 @@ import pathlib
 import re
 import unittest
 from collections.abc import Sized, Container, Iterable, Mapping, MutableMapping
-from unittest import mock
 from urllib.parse import unquote
 import aiohttp.web
 from aiohttp import hdrs
-from aiohttp.web import (UrlDispatcher, Request, Response,
+from aiohttp.web import (UrlDispatcher, Response,
                          HTTPMethodNotAllowed, HTTPNotFound,
                          HTTPCreated)
-from aiohttp.multidict import CIMultiDict
-from aiohttp.protocol import HttpVersion, RawRequestMessage
 from aiohttp.web_urldispatcher import (_defaultExpectHandler,
                                        DynamicRoute,
                                        PlainRoute,
@@ -20,6 +17,7 @@ from aiohttp.web_urldispatcher import (_defaultExpectHandler,
                                        ResourceRoute,
                                        AbstractResource,
                                        View)
+from aiohttp.test_utils import make_mocked_request
 
 
 class TestUrlDispatcher(unittest.TestCase):
@@ -33,16 +31,7 @@ class TestUrlDispatcher(unittest.TestCase):
         self.loop.close()
 
     def make_request(self, method, path):
-        self.app = mock.Mock()
-        message = RawRequestMessage(method, path, HttpVersion(1, 1),
-                                    CIMultiDict(), [], False, False)
-        self.payload = mock.Mock()
-        self.transport = mock.Mock()
-        self.reader = mock.Mock()
-        self.writer = mock.Mock()
-        req = Request(self.app, message, self.payload,
-                      self.transport, self.reader, self.writer)
-        return req
+        return make_mocked_request(method, path)
 
     def make_handler(self):
 
@@ -576,56 +565,6 @@ class TestUrlDispatcher(unittest.TestCase):
             handler = self.make_handler()
             self.router.add_route('INVALID_METHOD', '/path', handler)
 
-    def test_static_handle_eof(self):
-        loop = mock.Mock()
-        route = self.router.add_static('/st',
-                                       os.path.dirname(aiohttp.__file__))
-        with mock.patch('aiohttp.web_urldispatcher.os') as m_os:
-            out_fd = 30
-            in_fd = 31
-            fut = asyncio.Future(loop=self.loop)
-            m_os.sendfile.return_value = 0
-            route._sendfile_cb(fut, out_fd, in_fd, 0, 100, loop, False)
-            m_os.sendfile.assert_called_with(out_fd, in_fd, 0, 100)
-            self.assertTrue(fut.done())
-            self.assertIsNone(fut.result())
-            self.assertFalse(loop.add_writer.called)
-            self.assertFalse(loop.remove_writer.called)
-
-    def test_static_handle_again(self):
-        loop = mock.Mock()
-        route = self.router.add_static('/st',
-                                       os.path.dirname(aiohttp.__file__))
-        with mock.patch('aiohttp.web_urldispatcher.os') as m_os:
-            out_fd = 30
-            in_fd = 31
-            fut = asyncio.Future(loop=self.loop)
-            m_os.sendfile.side_effect = BlockingIOError()
-            route._sendfile_cb(fut, out_fd, in_fd, 0, 100, loop, False)
-            m_os.sendfile.assert_called_with(out_fd, in_fd, 0, 100)
-            self.assertFalse(fut.done())
-            loop.add_writer.assert_called_with(out_fd, route._sendfile_cb,
-                                               fut, out_fd, in_fd, 0, 100,
-                                               loop, True)
-            self.assertFalse(loop.remove_writer.called)
-
-    def test_static_handle_exception(self):
-        loop = mock.Mock()
-        route = self.router.add_static('/st',
-                                       os.path.dirname(aiohttp.__file__))
-        with mock.patch('aiohttp.web_urldispatcher.os') as m_os:
-            out_fd = 30
-            in_fd = 31
-            fut = asyncio.Future(loop=self.loop)
-            exc = OSError()
-            m_os.sendfile.side_effect = exc
-            route._sendfile_cb(fut, out_fd, in_fd, 0, 100, loop, False)
-            m_os.sendfile.assert_called_with(out_fd, in_fd, 0, 100)
-            self.assertTrue(fut.done())
-            self.assertIs(exc, fut.exception())
-            self.assertFalse(loop.add_writer.called)
-            self.assertFalse(loop.remove_writer.called)
-
     def fill_routes(self):
         route1 = self.router.add_route('GET', '/plain', self.make_handler())
         route2 = self.router.add_route('GET', '/variable/{name}',
